==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/PersistenceParser__24StringHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$StringHandlerCreator

// class file dependencies
// @dep_class c569d3b60da0bb7 gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *);

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/PersistenceParser__24StringHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$StringHandlerCreator

// class file dependencies
// @dep_class 931495f7d52215ef gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24StringHandlerCreator_H_ */
